@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with doodle; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -63,11 +63,11 @@ static int very_verbose = 0;
  */
 static void printHelp () {
   static Help help[] = {
-    { 'a', "approximate", "DISTANCE",
+    { 'a', "approximate", gettext_noop ("DISTANCE"),
       gettext_noop("consider strings to match if DISTANCE letters are different") },
     { 'b', "build", NULL,
       gettext_noop("build database (default is to search)") },
-    { 'd', "database", "FILENAME",
+    { 'd', "database", gettext_noop ("FILENAME"),
       gettext_noop("use location FILENAME to store doodle database") },
     { 'e', "extract", NULL,
       gettext_noop("for each matching file, print the extracted keywords") },
@@ -77,9 +77,9 @@ static void printHelp () {
       gettext_noop("print this help page") },
     { 'i', "ignore-case", NULL,
       gettext_noop("be case-insensitive (use when searching)") },
-    { 'l', "library", "LIBRARY",
+    { 'l', "library", gettext_noop ("LIBRARY"),
       gettext_noop("load an extractor plugin named LIBRARY") },
-    { 'L', "log", "FILENAME",
+    { 'L', "log", gettext_noop ("FILENAME"),
       gettext_noop("log keywords to a file named FILENAME") },
     { 'n', "nodefault", NULL,
       gettext_noop("do not load default set of extractor plugins") },
@@ -184,10 +184,10 @@ static int do_index(const char * filename,
     return 0; /* already processed */
   if (0 != stat(filename,
 		&sbuf)) {
-    printf(_("Call to '%s' for file '%s' failed: %s\n"),
-	   "stat",
-	   filename,
-	   strerror(errno));
+    fprintf(stderr, _("Call to '%s' for file '%s' failed: %s\n"),
+	    "stat",
+	    filename,
+	    strerror(errno));
     return 0;
   }
   if (S_ISREG(sbuf.st_mode)) {
@@ -215,14 +215,15 @@ static int build(const char * libraries,
   char * ename;
 
   if (dbName == NULL) {
-    printf(_("No database specified.  Aborting.\n"));
+    fprintf(stderr, _("No database specified.  Aborting.\n"));
     return -1;
   }
   for (i=strlen(dbName);i>=0;i--) {
     if (dbName[i] == ':') {
-      printf(_("'%s' is an invalid database filename (has a colon) for building database (option '%s').\n"),
-	     dbName,
-	     "-b");
+      fprintf(stderr,
+	      _("'%s' is an invalid database filename (has a colon) for building database (option '%s').\n"),
+	      dbName,
+	      "-b");
       return -1;
     }
   }
@@ -252,9 +253,9 @@ static int build(const char * libraries,
   if (log != NULL) {
     cls.logFile = fopen(log, "w+");
     if (cls.logFile == NULL)
-      printf(_("Could not open '%s' for logging: %s.\n"),
-	     log,
-	     strerror(errno));
+      fprintf(stderr, _("Could not open '%s' for logging: %s.\n"),
+	      log,
+	      strerror(errno));
   }
 
   ret = 0;
@@ -340,15 +341,15 @@ static int print(const char * dbName) {
   int ret;
 
  if (dbName == NULL) {
-    printf(_("No database specified. Aborting.\n"));
+    fprintf(stderr, _("No database specified. Aborting.\n"));
     return -1;
   }
   ename = expandFileName(dbName);
   if (0 != stat(ename, &buf)) {
-    printf(_("Call to '%s' for file '%s' failed: %s.\n"),
-	   "stat",
-	   dbName,
-	   strerror(errno));
+    fprintf(stderr, _("Call to '%s' for file '%s' failed: %s.\n"),
+	    "stat",
+	    dbName,
+	    strerror(errno));
     free(ename);
     return -1;
   }
@@ -379,15 +380,15 @@ static int search(const char * libraries,
   char * utf;
 
   if (dbName == NULL) {
-    printf(_("No database specified. Aborting.\n"));
+    fprintf(stderr, _("No database specified. Aborting.\n"));
     return -1;
   }
   ename = expandFileName(dbName);
   if (0 != stat(ename, &buf)) {
-    printf(_("Call to '%s' for file '%s' failed: %s.\n"),
-	   "stat",
-	   dbName,
-	   strerror(errno));
+    fprintf(stderr, _("Call to '%s' for file '%s' failed: %s.\n"),
+	    "stat",
+	    dbName,
+	    strerror(errno));
     free(ename);
     return -1;
   }
@@ -420,16 +421,20 @@ static int search(const char * libraries,
   args.seen_count = 0;
 
   for (i=0;i<argc;i++) {
-    printf(_("Searching for '%s':\n"),
-	   argv[i]);
+    if(verbose) {
+      printf(_("Searching for '%s':\n"),
+	     argv[i]);
+    }
     if (strlen(argv[i]) > MAX_LENGTH) {
-      printf(_("Warning: search string is longer than %d characters, search will not work.\n"),
-	     MAX_LENGTH);
+      fprintf(stderr,
+	      _("Warning: search string is longer than %d characters, search will not work.\n"),
+	      MAX_LENGTH);
       continue; /* no need to even try... */
     }
     if (strlen(argv[i]) > MAX_LENGTH/2) {
-      printf(_("Warning: search string is longer than %d characters, search may not work properly.\n"),
-	     MAX_LENGTH/2);
+      fprintf(stderr,
+	      _("Warning: search string is longer than %d characters, search may not work properly.\n"),
+	      MAX_LENGTH/2);
     }
     utf = convertToUtf8(argv[i],
 			strlen(argv[i]),
@@ -440,7 +445,9 @@ static int search(const char * libraries,
 				  utf,
 				  (DOODLE_ResultCallback) &printIt,
 				  &args)) {
-	printf(_("\tNot found!\n"));
+	if(verbose) {
+	  printf(_("\tNot found!\n"));
+	}
 	ret++;
       }
     } else {
@@ -450,7 +457,9 @@ static int search(const char * libraries,
 					 utf,
 					 (DOODLE_ResultCallback) &printIt,
 					 &args)) {
-	printf(_("\tNot found!\n"));
+	if (verbose) {
+	  printf(_("\tNot found!\n"));
+	}
 	ret++;
       }
     }
@@ -520,31 +529,36 @@ int main(int argc,
     switch (c) {
     case 'a':
       if (1 != sscanf(optarg, "%ud", &do_approx)) {
-	printf(_("You must pass a number to the '%s' option.\n"),
-	       "-a");
+	fprintf(stderr,
+		_("You must pass a number to the '%s' option.\n"),
+		"-a");
 	return -1;
       }
       if (do_build == 1) {
-	printf(_("The options '%s' and '%s' cannot be used together!\n"),
-	       "-a", "-b");
+	fprintf(stderr,
+		_("The options '%s' and '%s' cannot be used together!\n"),
+		"-a", "-b");
 	return -1;
-      }	
+      }
       break;
     case 'b':
       do_build = 1;
       if (do_approx != 0) {
-	printf(_("The options '%s' and '%s' cannot be used together!\n"),
-	       "-a", "-b");
+	fprintf(stderr,
+		_("The options '%s' and '%s' cannot be used together!\n"),
+		"-a", "-b");
 	return -1;
-      }	
+      }
       if (do_print == 1) {
-	printf(_("The options '%s' and '%s' cannot be used together!\n"),
-	       "-b", "-p");
+	fprintf(stderr,
+		_("The options '%s' and '%s' cannot be used together!\n"),
+		"-b", "-p");
 	return -1;
-      }	
+      }
       if (ignore_case == 1) {
-	printf(_("The options '%s' and '%s' cannot be used together!\n"),
-	       "-b", "-i");
+	fprintf(stderr,
+		_("The options '%s' and '%s' cannot be used together!\n"),
+		"-b", "-i");
 	return -1;
       }
       break;
@@ -563,8 +577,9 @@ int main(int argc,
     case 'i':
       ignore_case = 1;
       if (do_build == 1) {
-	printf(_("The options '%s' and '%s' cannot be used together!\n"),
-	       "-b", "-i");
+	fprintf(stderr,
+		_("The options '%s' and '%s' cannot be used together!\n"),
+		"-b", "-i");
 	return -1;
       }
       break;
@@ -576,12 +591,13 @@ int main(int argc,
       break;
     case 'm':
       if (1 != sscanf(optarg, "%u", &mem_limit)) {
-	printf(_("You must pass a number to the '%s' option.\n"),
-	       "-m");
+	fprintf(stderr,
+		_("You must pass a number to the '%s' option.\n"),
+		"-m");
 	return -1;
       }
       if (mem_limit > 0xFFFFFFFF / 1024 / 1024) {
-	printf(_("Specified memory limit is too high.\n"));
+	fprintf(stderr, _("Specified memory limit is too high.\n"));
 	return -1;
       }
       mem_limit *= 1024 * 1024;
@@ -592,10 +608,11 @@ int main(int argc,
     case 'p':
       do_print = 1;
       if (do_build == 1) {
-	printf(_("The options '%s' and '%s' cannot be used together!\n"),
-	       "-b", "-p");
+	fprintf(stderr,
+		_("The options '%s' and '%s' cannot be used together!\n"),
+		"-b", "-p");
 	return -1;
-      }	
+      }
       break;
     case 'P':
       prunepaths = optarg;
