@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with doodle; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -327,7 +327,7 @@ getKeywords(struct EXTRACT_Process * eproc,
       return NULL;
   if (eproc->pid == -1)
     return NULL;
-  fprintf(stderr, "Processing file %s\n", filename);
+  fprintf(stderr, _("Processing file %s\n"), filename);
   head = NULL;
   pos = NULL;
   next = NULL;
