@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with doodle; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -396,7 +396,7 @@ static unsigned long long LSEEK(BIO * bio,
 }
 
 static void IO_FREE(BIO * bio) {
-  flush_buffer(bio);		
+  flush_buffer(bio);
   close(bio->fd);
   free(bio->buffer);
   free(bio);
@@ -918,11 +918,9 @@ static void processShrink(SuffixTree * tree,
 			  STNode * pos,
 			  unsigned int * kept) {
   int mark;
-  STNode * next;
 
   while (pos != NULL) {
     (*kept)++;
-    next = NULL;
     mark = 0;
     if (ktP >= 0) {
       if (pos->link == keepThese[ktP])
@@ -1019,7 +1017,7 @@ static void processShrink(SuffixTree * tree,
   }
   CHECK(tree);
 }
-			
+
 /**
  * Reduce the memory consumption by dumping unused portions of
  * the suffix tree to disk.
@@ -1043,7 +1041,7 @@ static void shrinkMemoryFootprint(SuffixTree * tree,
   tree->mutationCount = 0;
   tree->log(tree->context,
 	    DOODLE_LOG_VERY_VERBOSE,
-	    _("Memory limit (%u bytes) hit, serializing some data.\n"),	
+	    _("Memory limit (%u bytes) hit, serializing some data.\n"),
 	    tree->used_memory);
   pos = keep;
   keepThese = NULL;
@@ -1142,7 +1140,7 @@ static STNode * lazyReadNode(SuffixTree * tree,
 
       if (mls == 0) {
 	if (-1 == READALL(tree->fd, &c, sizeof(unsigned char)))
-	  goto ERROR_ABORT;	
+	  goto ERROR_ABORT;
       } else {
 	c = ret[mls-1].c[0] + 1;
       }
@@ -1415,7 +1413,7 @@ static unsigned long long writeNode(BIO * fd,
     WRITEALL(fd, &node->clength, sizeof(unsigned char));
 #if USE_CI_CACHE
     cix = node->cix;
-    ciy = node->c - tree->cis[node->cix];	
+    ciy = node->c - tree->cis[node->cix];
 #else
     cix = -1;
     ciy = -1;
@@ -1504,7 +1502,7 @@ static unsigned long long writeNode(BIO * fd,
 	 node->matchCount,
 	 (node->matchCount > 0) ? node->matches[0] : -1,
 	 node[node->mls_size-1].link_off,
-	 node->next_off,	
+	 node->next_off,
 	 LSEEK(fd, 0, SEEK_CUR));
 #endif
 
@@ -1632,7 +1630,7 @@ SuffixTree * DOODLE_tree_create_internal(DOODLE_Logger log,
 	      DOODLE_LOG_CRITICAL,
 	      _("Could not unlink '%s': %s\n"),
 	      database,
-	      strerror(errno));	
+	      strerror(errno));
 	fd = NULL;
 	goto FRESH_START;
       } else {
@@ -1947,11 +1945,9 @@ void DOODLE_tree_destroy(SuffixTree * tree) {
     for (i=tree->fnc-1;i>=0;i--) {
       char * fn;
       int slen;
-      int xslen;
 
       fn = tree->filenames[i].filename;
       slen = strlen(fn);
-      xslen = slen;
       while ( (fn[slen] != '/') && (slen > 0) )
 	slen--;
       for (j=ptc-1;j>=0;j--)
@@ -2022,7 +2018,7 @@ void DOODLE_tree_destroy(SuffixTree * tree) {
 		    tree->database))
       tree->log(tree->context,
 		DOODLE_LOG_CRITICAL,
-		_("Could not rename temporary file '%s' to '%s: %s\n"),
+		_("Could not rename temporary file '%s' to '%s': %s\n"),
 		tdatabase,
 		tree->database,
 		strerror(errno));
@@ -2199,7 +2195,7 @@ static STNode * tree_search_internal(SuffixTree * tree,
 	if (pos->c[i] != ss[0])
 	  return NULL;
 	ss++;
-      }				
+      }
       if (ss[0] == '\0')
 	break;
       if (pos->child == NULL) {
@@ -2357,11 +2353,11 @@ int DOODLE_tree_expand(struct DOODLE_SuffixTree * tree,
 		  __FILE__, __LINE__);
 #if DEBUG
 	abort();
-#endif	
+#endif
 	cix = -1;
       }
 #endif
-    }			
+    }
 #endif
     if (cix == -1) {
       if (tree->cisLen == tree->cisPos) {
@@ -2410,7 +2406,7 @@ int DOODLE_tree_expand(struct DOODLE_SuffixTree * tree,
     if (cisp0[0] < pos->c[0]) {
       STNode * insert;
       /* head (non-mls) insert here! */
-      insert = MALLOC(sizeof(STNode));	
+      insert = MALLOC(sizeof(STNode));
       insert->mls_size = 1;
       insert->useCounter = 0;
       insert->link = pos;
@@ -2442,9 +2438,9 @@ int DOODLE_tree_expand(struct DOODLE_SuffixTree * tree,
 		(i < strlen(cisp0)) &&
 		(pos->c[i] == cisp0[i]) )
 	  i++;
-	
+
 	if ( (i > 1) &&
-	     (i < pos->clength) ) {	
+	     (i < pos->clength) ) {
 	  /* eat 1 < i < clength characters, create new
 	     child by splitting current string at i */
 	  tree_split(tree,
@@ -2471,7 +2467,7 @@ int DOODLE_tree_expand(struct DOODLE_SuffixTree * tree,
 	  if (pos->next_off != 0) {
 	    if (-1 == loadChild(tree,
 				pos))
-	      return 1;	
+	      return 1;
 	  } else {
 	    tree->modified = 1;
 	    pos->child = MALLOC(sizeof(STNode));
@@ -2488,7 +2484,7 @@ int DOODLE_tree_expand(struct DOODLE_SuffixTree * tree,
 	    break; /* strlen(cisp0) > 0! */
 	  }
 	}
-	pos = pos->child;	
+	pos = pos->child;
       } else {
 	if (pos->link == NULL) {
 	  if (pos->link_off != 0) {
@@ -2552,7 +2548,7 @@ int DOODLE_tree_expand(struct DOODLE_SuffixTree * tree,
 	    STNode * mlsroot;
 	    STNode * mlsnew;
 	    int mls;
-	
+
 	    /* use mls! */
 	    if (pos->clength != 1) {
 	      /* need to split tree first to make mls possible */
@@ -2566,7 +2562,7 @@ int DOODLE_tree_expand(struct DOODLE_SuffixTree * tree,
 		    (mlsroot->parent->link == mlsroot) &&
 		    (mlsroot->parent->mls_size > 1) )
 	      mlsroot = mlsroot->parent;
-	
+
 	    if (pos->link->c[0] == cisp0[0] + 1) {
 	      /* JOIN two mls segments (the new character fills the gap)! */
 	      if (pos->link->clength != 1) {
@@ -2586,7 +2582,7 @@ int DOODLE_tree_expand(struct DOODLE_SuffixTree * tree,
 	      }
 #endif
 	      mlsnew = MALLOC(sizeof(STNode) * (mlsroot->mls_size + pos->link->mls_size + 1));
-	
+
 	      memcpy(mlsnew,
 		     mlsroot,
 		     sizeof(STNode) * (mlsroot->mls_size));
@@ -2594,7 +2590,7 @@ int DOODLE_tree_expand(struct DOODLE_SuffixTree * tree,
 	      memcpy(&mlsnew[mlsroot->mls_size+1],
 		     pos->link,
 		     sizeof(STNode) * (pos->link->mls_size));
-	
+
 	      /* adjust data in copy */
 	      mlsnew[0].mls_size = mlsroot->mls_size + pos->link->mls_size + 1;
 	      for (mls=1;mls<mlsnew->mls_size;mls++) {
@@ -2604,17 +2600,17 @@ int DOODLE_tree_expand(struct DOODLE_SuffixTree * tree,
 	      }
 	      for (mls=0;mls<mlsnew->mls_size;mls++)
 		if (mlsnew[mls].child != NULL)
-		  mlsnew[mls].child->parent = &mlsnew[mls];	
-	
+		  mlsnew[mls].child->parent = &mlsnew[mls];
+
 	      /* update link to next entry */
 	      mlsnew[mlsnew->mls_size-1].link = pos->link[pos->link->mls_size-1].link;
 	      mlsnew[mlsnew->mls_size-1].link_off = pos->link[pos->link->mls_size-1].link_off;
 	      if (pos->link[pos->link->mls_size-1].link != NULL)
 		pos->link[pos->link->mls_size-1].link->parent = &mlsnew[mlsnew->mls_size-1];
-	
+
 	      /* update data in new entry */
 	      mlsnew[mlsroot->mls_size].c = 1 + &CIS[(unsigned char) mlsnew[mlsroot->mls_size-1].c[0]];
-	
+
 	      /* update link from parent */
 	      if (mlsroot->parent != NULL) {
 		mlsnew[0].parent = mlsroot->parent;
@@ -2646,21 +2642,21 @@ int DOODLE_tree_expand(struct DOODLE_SuffixTree * tree,
 #endif
 		tree->root = mlsnew;
 	      }
-	
+
 	      /* update pos to point to new location */
 	      free(pos->link);
 	      pos = &mlsnew[mlsroot->mls_size];
 	      /* end joining 2 mls segments */
 	    } else {
 	      /* EXTEND existing mls segment by one entry! */
-	      mlsnew = MALLOC(sizeof(STNode) * (mlsroot->mls_size + 1));	
+	      mlsnew = MALLOC(sizeof(STNode) * (mlsroot->mls_size + 1));
 	      memcpy(mlsnew,
 		     mlsroot,
 		     sizeof(STNode) * (mlsroot->mls_size));
-	      mlsnew[mlsroot->mls_size].clength = 1;	
+	      mlsnew[mlsroot->mls_size].clength = 1;
 
 	      /* adjust data in copy */
-	      mlsnew[0].mls_size = mlsroot->mls_size+1;	
+	      mlsnew[0].mls_size = mlsroot->mls_size+1;
 	      for (mls=1;mls<mlsnew->mls_size;mls++) {
 		mlsnew[mls].mls_size = mlsnew->mls_size - mls;
 		mlsnew[mls].parent = &mlsnew[mls-1];
@@ -2668,18 +2664,18 @@ int DOODLE_tree_expand(struct DOODLE_SuffixTree * tree,
 	      }
 	      for (mls=0;mls<mlsnew->mls_size;mls++)
 		if (mlsnew[mls].child != NULL)
-		  mlsnew[mls].child->parent = &mlsnew[mls];	
-	
+		  mlsnew[mls].child->parent = &mlsnew[mls];
+
 	      /* update link to next entry */
 	      mlsnew[mlsnew->mls_size-1].link = pos->link;
 	      mlsnew[mlsnew->mls_size-1].link_off = pos->link_off;
 	      if (pos->link != NULL)
 		pos->link->parent = &mlsnew[mlsnew->mls_size-1];
-	
+
 	      /* update data in new entry */
-	      mlsnew[mlsroot->mls_size].c 
+	      mlsnew[mlsroot->mls_size].c
 		= 1 + &CIS[(unsigned char) mlsnew[mlsroot->mls_size-1].c[0]];
-#if ASSERTS	
+#if ASSERTS
 	      if (mlsnew[mlsroot->mls_size].c[0] != cisp0[0]) {
 		tree->log(tree->context,
 			  DOODLE_LOG_CRITICAL,
@@ -2722,14 +2718,14 @@ int DOODLE_tree_expand(struct DOODLE_SuffixTree * tree,
 	      /* update pos to point to new location */
 	      pos = &mlsnew[mlsroot->mls_size];
 	    }
-	    free(mlsroot);	
+	    free(mlsroot);
 	    tree->used_memory += sizeof(STNode);
-	    tree->modified = 1;	  	
+	    tree->modified = 1;
 	    CHECK(tree);
 	    for (mls=0;mls<mlsnew->mls_size;mls++)
 	      markModified(&mlsnew[mls]);
 
-#if ASSERTS	
+#if ASSERTS
 	    if (*pos->c != cisp0[0]) {
 	      tree->log(tree->context,
 			DOODLE_LOG_CRITICAL,
@@ -2742,13 +2738,13 @@ int DOODLE_tree_expand(struct DOODLE_SuffixTree * tree,
 	  } else {
 	    STNode * insert;
 	    /* normal (non-mls) insert here!  */
-	    insert = MALLOC(sizeof(STNode));	
+	    insert = MALLOC(sizeof(STNode));
 	    insert->mls_size = 1;
 	    insert->useCounter = 0;
 	    insert->link = pos->link;
 	    insert->link_off = pos->link_off;
 	    pos->link = insert;
-	    pos->link_off = 0;	
+	    pos->link_off = 0;
 	    insert->parent = pos;
 	    insert->link->parent = insert;
 	    tree->modified = 1;
@@ -2757,12 +2753,12 @@ int DOODLE_tree_expand(struct DOODLE_SuffixTree * tree,
 	    /* for now (for check), fixed later */
 	    pos->c = &CIS[(unsigned char)cisp[0]];
 	    pos->clength = 1;
-	    CHECK(tree);	
+	    CHECK(tree);
 	    markModified(pos);
 	    break; /* strlen(cisp0) > 0! */
 	  }
 	} else {
-	  pos = pos->link;	
+	  pos = pos->link;
 	}
       }
     } /* end 'MORE: while-loop */
@@ -2806,7 +2802,7 @@ CLEANUP_SUCCESS:
   if (tree->used_memory > tree->memory_limit)
     shrinkMemoryFootprint(tree, tree->root);
 
-  return 0; 	
+  return 0;
 }
 
 static int truncate_internal(SuffixTree * tree,
@@ -3208,7 +3204,7 @@ static int tree_search_approx_internal(STNode * pos,
 				     tree,
 				     pos,
 				     callback,
-				     arg);	
+				     arg);
 	if (iret == -1)
 	  return -1;
 	ret += iret;
@@ -3502,7 +3498,7 @@ JNIEXPORT void JNICALL Java_org_gnunet_doodle_Doodle_truncate
 
   fn = (*env)->GetStringUTFChars(env,
 				 filename,
-				 &isCopy);	
+				 &isCopy);
   DOODLE_tree_truncate(ret->dst,
 		       fn);
   (*env)->ReleaseStringUTFChars(env,
@@ -3525,10 +3521,10 @@ JNIEXPORT jboolean JNICALL Java_org_gnunet_doodle_Doodle_expand
 
   fn = (*env)->GetStringUTFChars(env,
 				 filename,
-				 &isCopy);	
+				 &isCopy);
   ky = (*env)->GetStringUTFChars(env,
 				 key,
-				 &isCopy);	
+				 &isCopy);
   i = DOODLE_tree_expand(ret->dst,
 			 ky,
 			 fn);
@@ -3556,7 +3552,7 @@ JNIEXPORT jlong JNICALL Java_org_gnunet_doodle_Doodle_lastModified
 
   fn = (*env)->GetStringUTFChars(env,
 				 filename,
-				 &isCopy);	
+				 &isCopy);
   for (i=DOODLE_getFileCount(ret->dst)-1;i>=0;i--) {
     f = DOODLE_getFileAt(ret->dst, i);
     if (0 == strcmp(fn, f->filename)) {
@@ -3606,7 +3602,7 @@ JNIEXPORT jint JNICALL Java_org_gnunet_doodle_Doodle_search
 
   ky = (*env)->GetStringUTFChars(env,
 				 key,
-				 &isCopy);	
+				 &isCopy);
   vector = (*env)->GetObjectClass(env,
 				  vect);
   cls.env = env;
